<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_9c050c786fc87170cbb8" . "4fc6a8b13cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_1d6c68a0262e8fa0be" . "d1215b7224a98e" => base64_decode("cmVjaXBpZ" . "W50"), "_a1e707d02a236dadebd15a45e65ebd" . "b6" => base64_decode("YXR0YWNobWVu" . "dC1jb3VudA=="), "_618a4ae" . "b9fecc45" . "92a4521f" . "34876fa2" . "9" => base64_decode("ZnJ" . "vbQ" . "=="), "_44e986c04f41a08b56" . "a383c7b3a88ee2" => base64_decode("c2VuZ" . "GVy"), "_8c575917cbaedf1e7efae849" . "39402bff" => base64_decode("U3Viam" . "VjdA=="), "_97ea09a7faf27c5" . "2c6eff69773df1d8" . "a" => base64_decode("dGl" . "tZX" . "N0Y" . "W1w"), "_d706c160e45bf7434fff8" . "2a5976f0e19" => base64_decode("YXJyYXlfa2V5c" . "w=="), "_956cd32298a229" . "f9768f1096f077a" . "ce3" => base64_decode("Ym9keS1wb" . "GFpbg=="), "_f39f5346e313e4dd1ac3a7bd8032be" . "da" => base64_decode("c3Vic3RyX2NvbXBhcmU" . "="), "_6e1c717cf3cbf1af98" . "2ed74d4336b7f1" => base64_decode("Ym9ke" . "S1odG" . "1s"), "_f589476007fa133f457c3ef29ddfa56" . "6" => base64_decode("V" . "G" . "8" . "="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_d706c160e45bf7434" . "fff82a5976f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_a1e707d02a" . "236dadebd15" . "a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f39f5346e313e4dd1ac3a7bd8032" . "beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9c050c786fc87170c" . "bb84fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_1d6c68a0262e8fa0be" . "d1215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_618a4aeb9fecc4592" . "a4521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_8c575917cbaedf1e7ef" . "ae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_6e1c717cf3cbf1af982ed74d4336b7f" . "1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_956cd3229" . "8a229f9768" . "f1096f077a" . "ce3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_97ea09a7faf27c52c6eff69" . "773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_44e986c04f41a" . "08b56a383c7b3a" . "88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}